@@ -49,7 +49,7 @@ def test_xtb_task_gfn1xtb_m01():
     atomic_result = qcng.compute(atomic_input, "xtb")
 
     assert atomic_result.success
-    assert pytest.approx(atomic_result.return_result, thr) == return_result
+    assert pytest.approx(atomic_result.return_result, abs=thr) == return_result
 
 
 @using("xtb")
@@ -91,7 +91,7 @@ def test_xtb_task_gfn1xtb_m02():
     atomic_result = qcng.compute(atomic_input, "xtb")
 
     assert atomic_result.success
-    assert pytest.approx(atomic_result.return_result, thr) == return_result
+    assert pytest.approx(atomic_result.return_result, abs=thr) == return_result
 
 
 @using("xtb")
@@ -132,7 +132,7 @@ def test_xtb_task_gfn1xtb_m03():
     atomic_result = qcng.compute(atomic_input, "xtb")
 
     assert atomic_result.success
-    assert pytest.approx(atomic_result.return_result, thr) == return_result
+    assert pytest.approx(atomic_result.return_result, abs=thr) == return_result
 
 
 @using("xtb")
@@ -173,8 +173,8 @@ def test_xtb_task_gfn1xtb_m04():
     atomic_result = qcng.compute(atomic_input, "xtb")
 
     assert atomic_result.success
-    assert pytest.approx(atomic_result.return_result["dipole"], thr) == return_result["dipole"]
-    assert pytest.approx(atomic_result.return_result["mulliken_charges"], thr) == return_result["mulliken_charges"]
+    assert pytest.approx(atomic_result.return_result["dipole"], abs=thr) == return_result["dipole"]
+    assert pytest.approx(atomic_result.return_result["mulliken_charges"], abs=thr) == return_result["mulliken_charges"]
     assert "mayer_indices" in atomic_result.return_result
 
 
@@ -194,7 +194,7 @@ def test_xtb_task_gfn1xtb_m05():
     atomic_result = qcng.compute(atomic_input, "xtb")
 
     assert atomic_result.success
-    assert pytest.approx(atomic_result.return_result, thr) == return_result
+    assert pytest.approx(atomic_result.return_result, abs=thr) == return_result
     assert "xtb" in atomic_result.extras
 
 
@@ -233,7 +233,7 @@ def test_xtb_task_gfn2xtb_m01():
     atomic_result = qcng.compute(atomic_input, "xtb")
 
     assert atomic_result.success
-    assert pytest.approx(atomic_result.return_result, thr) == return_result
+    assert pytest.approx(atomic_result.return_result, abs=thr) == return_result
 
 
 @using("xtb")
@@ -275,7 +275,7 @@ def test_xtb_task_gfn2xtb_m02():
     atomic_result = qcng.compute(atomic_input, "xtb")
 
     assert atomic_result.success
-    assert pytest.approx(atomic_result.return_result, thr) == return_result
+    assert pytest.approx(atomic_result.return_result, abs=thr) == return_result
 
 
 @using("xtb")
@@ -316,7 +316,7 @@ def test_xtb_task_gfn2xtb_m03():
     atomic_result = qcng.compute(atomic_input, "xtb")
 
     assert atomic_result.success
-    assert pytest.approx(atomic_result.return_result, thr) == return_result
+    assert pytest.approx(atomic_result.return_result, abs=thr) == return_result
 
 
 @using("xtb")
@@ -357,8 +357,8 @@ def test_xtb_task_gfn2xtb_m04():
     atomic_result = qcng.compute(atomic_input, "xtb")
 
     assert atomic_result.success
-    assert pytest.approx(atomic_result.return_result["dipole"], thr) == return_result["dipole"]
-    assert pytest.approx(atomic_result.return_result["mulliken_charges"], thr) == return_result["mulliken_charges"]
+    assert pytest.approx(atomic_result.return_result["dipole"], abs=thr) == return_result["dipole"]
+    assert pytest.approx(atomic_result.return_result["mulliken_charges"], abs=thr) == return_result["mulliken_charges"]
     assert "mayer_indices" in atomic_result.return_result
 
 
@@ -378,7 +378,7 @@ def test_xtb_task_gfn2xtb_m05():
     atomic_result = qcng.compute(atomic_input, "xtb")
 
     assert atomic_result.success
-    assert pytest.approx(atomic_result.return_result, thr) == return_result
+    assert pytest.approx(atomic_result.return_result, abs=thr) == return_result
     assert "xtb" in atomic_result.extras
 
 
